LamsonProject: Downloading Lamson

#

# Downloading Lamson

You can get the Lamson source in various ways, read the releases documentation to find out how.

## Installing With Easy Install

Using easy_install is the easiest way to install, simply run “sudo easy_install lamson” and it will do the work of getting the dependencies and setting everything up.

## Installing With setup.py

Once you get the source, you can also use setup.py to install Lamson. First make sure that you have SQLAlchemy, Mako, and nose installed:

    $ sudo easy_install sqlalchemy
    $ sudo easy_install jinja
    $ sudo easy_install nose

If you refuse to use easy_install entirely then it is on you to find these projects and install them how you see best. *Make sure you have the most recent version of all dependencies.*

Then you can use this command to install:

    $ python setup.py install

## Installing Into A Virtual Env

Read the instructions for installing with virtual env in the documentation section.